# StrictDoc

![](https://github.com/stanislaw/strictdoc/actions/workflows/ci-mac.yml/badge.svg)
![](https://github.com/stanislaw/strictdoc/actions/workflows/ci-linux-ubuntu-latest.yml/badge.svg)
![](https://github.com/stanislaw/strictdoc/actions/workflows/ci-windows.yml/badge.svg)

The documentation is hosted on Read the Docs:
[StrictDoc documentation](https://strictdoc.readthedocs.io/en/stable/).
